

### Instructions for Using the Multiple Date Selection Component
**Step1 Intstall Datepicker package**
     npm install bootstrap5-multiple-react-datepicker
**Step2: Install Bootstrap & Add it to your Project**
      This package requires Bootstrap for styling. Depending on your setup, follow the appropriate instructions:
      **Step2 Option A** If You’re Using Plain Bootstrap: 
            Install Bootstrap and import its CSS file in your main JavaScript or SCSS file.
               npm install bootstrap@^5.3.2
            Then, in your main file (e.g., index.js or App.js), add
               import 'bootstrap/dist/css/bootstrap.min.css';
       **Step2 Option B**
       For SCSS-based imports (if using custom Bootstrap styles): Add this to your main SCSS file:
`               @import '~bootstrap/scss/bootstrap';
      Add Your Global SCSS Import: In your main JavaScript file (e.g., index.js or App.js), import the global SCSS file to apply Bootstrap styles across your application.
               import '../styles/globals.scss'; // Ensure this file imports Bootstrap
      **Step3 Option C If You’re Using React-Bootstrap:**
               import 'bootstrap/dist/css/bootstrap.min.css';

 **Step3 Import the Date Picker**
   - Import the necessary React hooks (`useState` and `useRef`) and styles to use the Datepicker component in your app. 
   - Your import statements should look like this:
     ```javascript
     import { useState, useRef } from 'react';
    import Datepicker from 'bootstrap5-multiple-react-datepicker';


2. **Define State Variables**
   - Inside your main component (e.g., `App`), define the state variables for managing date selections.
   - Use `multiple` to determine if multiple dates are allowed.
   - Use `selecteddate` for single date selection and `selecteddatesMulti` for multiple date selections.

   Example:
   ```javascript
   const [multiple, setMultiple] = useState(''); // Empty for single date selection, 'yes' for multiple
   const [selecteddate, setSelecteddate] = useState('');
   const [selecteddatesMulti, setSelecteddatesMulti] = useState([]);
   ```

3. **Create a Callback Function for Date Changes**
   - Define the `handleDateChange` function to handle date changes. This function will receive `newdate` as an argument.
   - Check the type of `newdate`:
     - If it’s an object (array of dates for multiple selection), update `selecteddatesMulti`.
     - If it’s a single string, update `selecteddate`.

   Example:
   ```javascript
   const handleDateChange = (newdate) => {
       if (typeof newdate === 'object') {
           setSelecteddatesMulti(newdate); // Update multi-date state
       } else {
           setSelecteddate(newdate); // Update single date state
       }
   };
   ```

4. **Use the Datepicker Component**
   - Add the `Datepicker` component within the return statement of your `App` function.
   - Pass the following props:
     - `onDateChange`: Assign the `handleDateChange` function.
     - `dateprop`: Assign the correct date state based on the `multiple` selection state.
     - `multiple`: Pass `multiple` to indicate whether multiple selection is active.
     - `format`: Specify the date format, e.g., 
	YYYYMMDD
	DDMMYYYY
	MMDDYYYY
	
	     - `displaya`: Leave blank to use the default display mode (popup/modal).

   Example:
   ```javascript
   return (
       <Datepicker 
           onDateChange={handleDateChange}
           dateprop={multiple === 'yes' ? selecteddatesMulti : selecteddate}
           multiple={multiple}
           format="MMDDYYYY"
           displaya=""
       />
   );
   ```

5. **Run the App**
   - Start your development server to test the component.
   - Ensure that both single and multiple date selections function correctly according to the `multiple` state.

6. **Optional: Toggle between Single and Multiple Date Selection**
   - You can add a button or input element to toggle the `multiple` state between `''` (single) and `'yes'` (multiple) based on user preference.

---

This guide should give you a straightforward setup and usage for your multiple date selection component. Adjustments may be needed depending on specific requirements.


